==> 1.1.0.tar.gz: libresocial/README.md <==
# Libre Social
### Descripción

Fuentes de Letra [Fonts] para Redes sociales Libres y otros servicios descentralizados que apoyan el uso de Software Libre.

## Utilización

Copie los directorios __css__ y __fonts__ con sus archivos a su proyecto, y agregue una línea al _head_ de su archivo html.

Ejemplo:

```html
<link href="css/libresocial.css" rel="stylesheet"/>
```

Si usted es un experto puede reordenar sus directorios para mejor comodidad.

## Licencia
- La fuente Libre Social esta bajo la Licencia AGPLv3
  - https://www.gnu.org/licenses/agpl.html

## Log de Cambios
- v1.1.0 - Agrega Liberapay y Matrix
- v1.0.0 - publicación inicial

## Iconos disponibles

+ Diaspora
+ Friendica
+ GitLab
+ GNUSocial
+ Hubzilla
+ Liberapay
+ Mastodon
+ Matrix
+ MediaGoblin
+ Notabug
+ Pump
+ Tox
+ XMPP

## Contributor

- Email: heckyel [at] riseup [dot] net
- GNUSocial: https://gnusocial.net/heckyel

## Hacking en Libre Social

- Dependencias
  - FontForge (Se necesita de una versión >= 20140101)
  - Python >= 2.6 or 3

- Instrucciones

  - Fuente:
    Los íconos se localizan en 2 directorios __scr__ y __lab__.
    
    Explicando lo anterior: 
    
    __scr__: aquí se encuentran los archivos de imagen vectorial con sus __cuadrículas__ para ayudar a la edición futura de los mismos; así mismo encontrará un archivo llamado __template.svg__ el cual es una plantilla para crear futuras imágenes vectoriales que luego serán íconos.
    
    __lab__: aquí se encuentran los archivos de imagen vectorial listos para su compilación.
    
  - Edición de __metadata.json__
    
    Si usted agrega una nueva imagen vectorial, debe editar el archivo __metadata.json__:

    Ejemplo:
    
    ```html
    , "glyphs":
    { "0xe800": "diaspora.svg"
    , "0xe801": "friendica.svg"
    , "0xe802": "gitlab.svg"
    , "0xe803": "gnusocial.svg"
    , "0xe804": "hubzilla.svg"
    , "0xe805": "mastodon.svg"
    , "0xe806": "mediagoblin.svg"
    , "0xe807": "notabug.svg"
    , "0xe808": "pump.svg"
    , "0xe809": "tox.svg"
    , "0xe810": "xmpp.svg"
    , "0xe811": "nueva.svg"
    }
    ```
    La imagen vectorial nueva lleva por nombre _nueva.svg_, y su número de __glyphs__ respectivo es __0xe811__.
    También opcionalmente puede cambiar el __nombre de la fuente__, __copyright__, etc.
    
- Compilación:

    - Para realizar la compilación debemos estar en el directorio __lab__ y luego abrir la terminal en ese directorio.
    - Si usted agrega una nueva imagen vectorial, es necesario editar el archivo __metadata.json__
    
    Ejemplo:
    
    ```html
    ./svgs2ttf metadata.json
    ```
    
    - La salida de este comando, nos dará como resultado los siguientes archivos:
      - libresocial.ttf
      - libresocial.odf
      - libresocial.woff
      - libresocial.svg
      
    - Añadimos las nuevas fuentes (libresocial.ttf, libresocial.woff y libresocial.svg) al directorio __fonts__
    
    - Luego..., en el caso de haber agregado una nueva imagen vectorial, modifique el archivo _libresocial.css_ localizado en el directorio __css__:
    
    Ejemplo:
    
    Agregamos la imagen vectorial llamada __nueva__.svg a nuestra lista de íconos generada en pasos anteriores.
    
    ```html
    .icon-nueva:before { content: '\e811'; } /* '[]' */
    ```
    
    Por último usted agregaría el nombre del ícono _(icon-nueva)_ al archivo _demo.html_ para testear su nuevo ícono.
    
    Ejemplo:
    
    ```html
    <a class="nueva" href="#"><i class="icon-nueva"></i></a>
    ```
    
    Listo. Hasta aquí ya tendría su ícono agregado a su fuente tipográfica.

==> 1.1.1.tar.gz: libresocial/README.md <==
# Libre Social
### Descripción

Fuentes de Letra [Fonts] para Redes sociales Libres y otros servicios descentralizados que apoyan el uso de Software Libre.

## Utilización

Copie los directorios __css__ y __fonts__ con sus archivos a su proyecto, y agregue una línea al _head_ de su archivo html.

Ejemplo:

```html
<link href="css/libresocial.css" rel="stylesheet"/>
```

Si usted es un experto puede reordenar sus directorios para mejor comodidad.

## Licencia
- La fuente Libre Social esta bajo la Licencia AGPLv3
  - https://www.gnu.org/licenses/agpl.html

## Log de Cambios
- v1.1.0 - Agrega Liberapay y Matrix
- v1.0.0 - publicación inicial

## Iconos disponibles

+ Diaspora
+ Friendica
+ GitLab
+ GNUSocial
+ Hubzilla
+ Liberapay
+ Mastodon
+ Matrix
+ MediaGoblin
+ Notabug
+ Pump
+ Tox
+ XMPP

[![libresocial.png](https://s9.postimg.org/9dtncxbi7/libresocial.png)](https://postimg.org/image/9ql1j3trv/)

## Contributor

- Email: heckyel [at] riseup [dot] net
- GNUSocial: https://quitter.cl/heckyel

## Hacking en Libre Social

- Dependencias
  - FontForge (Se necesita de una versión >= 20140101)
  - Python >= 2.6 or 3

- Instrucciones

  - Fuente:
    Los íconos se localizan en 2 directorios __scr__ y __lab__.

    Explicando lo anterior:

    __scr__: aquí se encuentran los archivos de imagen vectorial con sus __cuadrículas__ para ayudar a la edición futura de los mismos; así mismo encontrará un archivo llamado __template.svg__ el cual es una plantilla para crear futuras imágenes vectoriales que luego serán íconos.

    __lab__: aquí se encuentran los archivos de imagen vectorial listos para su compilación.

  - Edición de __metadata.json__

    Si usted agrega una nueva imagen vectorial, debe editar el archivo __metadata.json__:

    Ejemplo:

    ```html
    , "glyphs":
    { "0xe800": "diaspora.svg"
    , "0xe801": "friendica.svg"
    , "0xe802": "gitlab.svg"
    , "0xe803": "gnusocial.svg"
    , "0xe804": "hubzilla.svg"
    , "0xe805": "mastodon.svg"
    , "0xe806": "mediagoblin.svg"
    , "0xe807": "notabug.svg"
    , "0xe808": "pump.svg"
    , "0xe809": "tox.svg"
    , "0xe810": "xmpp.svg"
    , "0xe811": "nueva.svg"
    }
    ```
    La imagen vectorial nueva lleva por nombre _nueva.svg_, y su número de __glyphs__ respectivo es __0xe811__.
    También opcionalmente puede cambiar el __nombre de la fuente__, __copyright__, etc.

- Compilación:

    - Para realizar la compilación debemos estar en el directorio __lab__ y luego abrir la terminal en ese directorio.
    - Si usted agrega una nueva imagen vectorial, es necesario editar el archivo __metadata.json__

    Ejemplo:

    ```html
    ./svgs2ttf metadata.json
    ```

    - La salida de este comando, nos dará como resultado los siguientes archivos:
      - libresocial.ttf
      - libresocial.odf
      - libresocial.woff
      - libresocial.svg

    - Añadimos las nuevas fuentes (libresocial.ttf, libresocial.woff y libresocial.svg) al directorio __fonts__

    - Luego..., en el caso de haber agregado una nueva imagen vectorial, modifique el archivo _libresocial.css_ localizado en el directorio __css__:

    Ejemplo:

    Agregamos la imagen vectorial llamada __nueva__.svg a nuestra lista de íconos generada en pasos anteriores.

    ```html
    .icon-nueva:before { content: '\e811'; } /* '[]' */
    ```

    Por último usted agregaría el nombre del ícono _(icon-nueva)_ al archivo _demo.html_ para testear su nuevo ícono.

    Ejemplo:

    ```html
    <a class="nueva" href="#"><i class="icon-nueva"></i></a>
    ```

    Listo. Hasta aquí ya tendría su ícono agregado a su fuente tipográfica.
